# Kisi

## Overview
KISI: The go-to access control app.

Library for Kisi. Kisi is an easy to use cloud based software to manage access to your doors. For physical access use your smartphone's mobile App or secure badges to unlock and open door.


[Kisi Shop](https://www.getkisi.com/pricing)

[About Kisi](https://www.getkisi.com/about)

Request Feature/Suggestion: https://forms.gle/efGD5DuTpWsX96GG7

[//]: # (## Download stats)

[//]: # ([![Downloads]&#40;https://static.pepy.tech/badge/ActiveCollab&#41;]&#40;https://pepy.tech/project/ActiveCollab&#41;)

## Installation
```console
pip install kisi
```
Kisi supports Python 3+.

## Usage

### Default
```python
import kisi

API_KEY = 'host_url' # Kisi Auth Key 

```
Generate Key from [Kisi API](https://web.kisi.io/user/api)
